==> realtime-qr-scanner-1.0.1.tgz: package/src/Component/QrCodeScanner/index.js <==
import React, { useEffect, useState } from "react";

const QrCodeScanner = ({ fps, width, height, title, scannedCallback }) => {
  const [scanner, setScanner] = useState(null);
  const [isScanning, setIsScanning] = useState(false);
  const [facingMode, setFacingMode] = useState("environment"); // Default to back camera

  useEffect(() => {
    const loadScript = () => {
      return new Promise((resolve, reject) => {
        if (document.getElementById("html5-qrcode-script")) {
          resolve();
          return;
        }

        const script = document.createElement("script");
        script.id = "html5-qrcode-script";
        script.src =
          "https://cdnjs.cloudflare.com/ajax/libs/html5-qrcode/2.3.8/html5-qrcode.min.js";
        script.integrity =
          "sha512-r6rDA7W6ZeQhvl8S7yRVQUKVHdexq+GAlNkNNqVC7YyIV+NwqCTJe2hDWCiffTyRNOeGEzRRJ9ifvRm/HCzGYg==";
        script.crossOrigin = "anonymous";
        script.referrerPolicy = "no-referrer";
        script.onload = () => resolve();
        script.onerror = () => reject(new Error("Failed to load script"));
        document.body.appendChild(script);
      });
    };

    loadScript()
      .then(() => {
        const qrReader = new Html5Qrcode("qr-reader");
        setScanner(qrReader);

        return () => {
          qrReader
            .stop()
            .catch((err) => console.log("Error stopping scanner:", err));
        };
      })
      .catch((err) => {
        console.error("Failed to load script:", err);
      });
  }, []);

  const startScanning = () => {
    if (scanner && !isScanning) {
      setIsScanning(true);
      scanner
        .start(
          { facingMode },
          { fps: 10, qrbox: { width: 250, height: 250 } },
          onScanSuccess,
          onScanError,
        )
        .catch((err) => {
          console.error("Failed to start scanning:", err);
          setIsScanning(false);
        });
    }
  };

  const stopScanning = () => {
    if (scanner) {
      scanner
        .stop()
        .then(() => {
          setIsScanning(false);
        })
        .catch((err) => console.error("Error stopping scanner:", err));
    }
  };

  const onScanSuccess = (decodedText) => {
    scannedCallback(decodedText);
    stopScanning();
  };

  const onScanError = (errorMessage) => {
    console.log("QR Code scan error:", errorMessage);
  };

  // Inline styles for the component
  const styles = {
    container: {
      width: width,
      margin: "20px auto",
      borderRadius: "10px",
      boxShadow: "0 4px 8px rgba(0, 0, 0, 0.2)",
      backgroundColor: "#fff",
      textAlign: "center",
      fontFamily: "Arial, sans-serif",
    },
    title: {
      fontSize: "24px",
      fontWeight: "bold",
      marginBottom: "15px",
      color: "#333",
    },
    qrReaderBox: {
      width: "100%",
      height: height,
      margin: "15px 0",
      border: "2px dashed #ddd",
      borderRadius: "8px",
      display: "flex",
      alignItems: "center",
      justifyContent: "center",
      backgroundColor: "#f9f9f9",
      position: "relative", // For positioning overlay
      overflow: "hidden", // To prevent overflow of video elements
    },
    video: {
      position: "absolute", // Position video absolutely within the container
      top: 0,
      left: 0,
      width: "100%", // Cover the container
      height: "100%", // Cover the container
      objectFit: "cover", // Maintain aspect ratio
      borderRadius: "8px", // Rounded corners
    },
    overlay: {
      position: "absolute",
      top: 0,
      left: 0,
      width: "100%",
      height: "100%",
      backgroundColor: "rgba(0, 0, 0, 0.5)", // Semi-transparent overlay
      borderRadius: "8px",
      display: isScanning ? "block" : "none", // Show overlay only while scanning
    },
    label: {
      display: "block",
      margin: "10px 0",
      fontSize: "14px",
      color: "#555",
    },
    select: {
      width: "100%",
      padding: "8px",
      marginTop: "5px",
      borderRadius: "5px",
      border: "1px solid #ddd",
      fontSize: "14px",
      backgroundColor: "#fafafa",
    },
    buttonContainer: {
      marginTop: "15px",
      display: "flex",
      justifyContent: "center",
      gap: "10px",
    },
    scanButton: {
      padding: "10px 20px",
      fontSize: "16px",
      border: "none",
      borderRadius: "5px",
      cursor: "pointer",
      color: "#fff",
      backgroundColor: isScanning ? "#9e9e9e" : "#4caf50",
      transition: "background-color 0.3s ease",
    },
    stopButton: {
      padding: "10px 20px",
      fontSize: "16px",
      border: "none",
      borderRadius: "5px",
      cursor: "pointer",
      color: "#fff",
      backgroundColor: "#f44336",
      transition: "background-color 0.3s ease",
    },
  };

  return (
    <div style={styles.container}>
      <div style={{ padding: 18 }}>
        <h2 style={styles.title}>{title}</h2>
        <div id="qr-reader" style={styles.qrReaderBox}>
          <video style={styles.video} autoPlay playsInline></video>{" "}
          {/* Video element for scanning */}
          <div style={styles.overlay} />{" "}
          {/* Overlay to darken the background while scanning */}
        </div>

        <label style={styles.label}>
          Select Camera:
          <select
            style={styles.select}
            value={facingMode}
            onChange={(e) => setFacingMode(e.target.value)}
          >
            <option value="environment">Back Camera</option>
            <option value="user">Front Camera</option>
          </select>
        </label>

        <div style={styles.buttonContainer}>
          <button
            style={styles.scanButton}
            onClick={startScanning}
            disabled={isScanning}
          >
            {isScanning ? "Scanning..." : "Start Scanning"}
          </button>
          {isScanning && (
            <button style={styles.stopButton} onClick={stopScanning}>
              Stop Scanning
            </button>
          )}
        </div>
      </div>
    </div>
  );
};

export default QrCodeScanner;

==> realtime-qr-scanner-1.0.2.tgz: package/src/Component/QrCodeScanner/index.js <==
import React, { useEffect, useRef, useState } from "react";
import { Html5Qrcode } from "html5-qrcode";

const QrCodeScanner = ({ fps, width, height, title, scannedCallback }) => {
  const [scanner, setScanner] = useState(null);
  const [isScanning, setIsScanning] = useState(false);
  const [facingMode, setFacingMode] = useState("environment");
  const qrReaderRef = useRef(null); // Create a ref for the QR reader container

  useEffect(() => {
    if (qrReaderRef.current) {
      const qrReader = new Html5Qrcode(qrReaderRef.current.id); // Use the ref's current element ID
      setScanner(qrReader);
    }
    return () => {
      stopScanning(); // Ensure the scanner is stopped on cleanup
    };
  }, [qrReaderRef]); // Dependency array ensures this effect runs when qrReaderRef changes

  const startScanning = () => {
    if (scanner && !isScanning) {
      setIsScanning(true);
      scanner
        .start(
          { facingMode },
          { fps: 10, qrbox: { width: 250, height: 250 } },
          onScanSuccess,
          onScanError
        )
        .then(() => {
          console.log("Scanning started");
        })
        .catch((err) => {
          console.error("Failed to start scanning:", err);
          setIsScanning(false);
        });
    } else {
      console.warn("Start scanning called, but scanner is not ready or already scanning");
    }
  };

  const stopScanning = () => {
    if (scanner && isScanning) {
      console.log("Stopping scanning");
      scanner
        .stop()
        .then(() => {
          console.log("Scanning stopped");
          setIsScanning(false);
        })
        .catch((err) => {
          console.error("Error stopping scanner:", err);
          setIsScanning(false);
        });
    } else {
      console.warn("Stop scanning called, but scanner is not running");
    }
  };

  const onScanSuccess = (decodedText) => {
    console.log("Scan success:", decodedText);
    scannedCallback(decodedText);
    stopScanning();
  };

  const onScanError = (errorMessage) => {
    // console.log("QR Code scan error:", errorMessage);
  };

  // Inline styles for the component
  const styles = {
    container: {
      width: width,
      margin: "20px auto",
      borderRadius: "10px",
      boxShadow: "0 4px 8px rgba(0, 0, 0, 0.2)",
      backgroundColor: "#fff",
      textAlign: "center",
      fontFamily: "Arial, sans-serif",
    },
    title: {
      fontSize: "24px",
      fontWeight: "bold",
      marginBottom: "15px",
      color: "#333",
    },
    qrReaderBox: {
      width: "100%",
      height: height,
      margin: "15px 0",
      border: "2px dashed #ddd",
      borderRadius: "8px",
      display: "flex",
      alignItems: "center",
      justifyContent: "center",
      backgroundColor: "#f9f9f9",
      position: "relative", // For positioning overlay
      overflow: "hidden", // To prevent overflow of video elements
    },
    video: {
      position: "absolute", // Position video absolutely within the container
      top: 0,
      left: 0,
      width: "100%", // Cover the container
      height: "100%", // Cover the container
      objectFit: "cover", // Maintain aspect ratio
      borderRadius: "8px", // Rounded corners
    },
    overlay: {
      position: "absolute",
      top: 0,
      left: 0,
      width: "100%",
      height: "100%",
      backgroundColor: "rgba(0, 0, 0, 0.5)", // Semi-transparent overlay
      borderRadius: "8px",
      display: isScanning ? "block" : "none", // Show overlay only while scanning
    },
    label: {
      display: "block",
      margin: "10px 0",
      fontSize: "14px",
      color: "#555",
    },
    select: {
      width: "100%",
      padding: "8px",
      marginTop: "5px",
      borderRadius: "5px",
      border: "1px solid #ddd",
      fontSize: "14px",
      backgroundColor: "#fafafa",
    },
    buttonContainer: {
      marginTop: "15px",
      display: "flex",
      justifyContent: "center",
      gap: "10px",
    },
    scanButton: {
      padding: "10px 20px",
      fontSize: "16px",
      border: "none",
      borderRadius: "5px",
      cursor: "pointer",
      color: "#fff",
      backgroundColor: isScanning ? "#9e9e9e" : "#4caf50",
      transition: "background-color 0.3s ease",
    },
    stopButton: {
      padding: "10px 20px",
      fontSize: "16px",
      border: "none",
      borderRadius: "5px",
      cursor: "pointer",
      color: "#fff",
      backgroundColor: "#f44336",
      transition: "background-color 0.3s ease",
    },
  };

  return (
    <div style={styles.container}>
      <div style={{ padding: 18 }}>
        <h2 style={styles.title}>{title}</h2>
        <div id="qr-reader" ref={qrReaderRef} style={styles.qrReaderBox}>
          {/* This element is referenced by the Html5Qrcode instance */}
          <video style={styles.video} autoPlay playsInline></video>
          <div style={styles.overlay} />
        </div>

        <label style={styles.label}>
          Select Camera:
          <select
            style={styles.select}
            value={facingMode}
            onChange={(e) => setFacingMode(e.target.value)}
          >
            <option value="environment">Back Camera</option>
            <option value="user">Front Camera</option>
          </select>
        </label>

        <div style={styles.buttonContainer}>
          <button
            style={styles.scanButton}
            onClick={startScanning}
            disabled={isScanning}
          >
            {isScanning ? "Scanning..." : "Start Scanning"}
          </button>
          {isScanning && (
            <button style={styles.stopButton} onClick={stopScanning}>
              Stop Scanning
            </button>
          )}
        </div>
      </div>
    </div>
  );
};

export default QrCodeScanner;
